@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -67,306 +67,26 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
-            { "ADP", "ADP" },
-            { "AED", "AED" },
-            { "AFA", "AFA" },
-            { "AFN", "AFN" },
-            { "ALK", "ALK" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "AOK", "AOK" },
-            { "AON", "AON" },
-            { "AOR", "AOR" },
-            { "ARA", "ARA" },
-            { "ARL", "ARL" },
-            { "ARM", "ARM" },
-            { "ARP", "ARP" },
-            { "ARS", "ARS" },
-            { "ATS", "ATS" },
             { "AUD", "AUD" },
-            { "AWG", "AWG" },
-            { "AZM", "AZM" },
-            { "AZN", "AZN" },
-            { "BAD", "BAD" },
-            { "BAM", "BAM" },
-            { "BAN", "BAN" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BEC", "BEC" },
-            { "BEF", "BEF" },
-            { "BEL", "BEL" },
-            { "BGL", "BGL" },
-            { "BGM", "BGM" },
-            { "BGN", "BGN" },
-            { "BGO", "BGO" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
-            { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BOL", "BOL" },
-            { "BOP", "BOP" },
-            { "BOV", "BOV" },
-            { "BRB", "BRB" },
-            { "BRC", "BRC" },
-            { "BRE", "BRE" },
             { "BRL", "BRL" },
-            { "BRN", "BRN" },
-            { "BRR", "BRR" },
-            { "BRZ", "BRZ" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BUK", "BUK" },
-            { "BWP", "BWP" },
-            { "BYB", "BYB" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
             { "CAD", "CAD" },
-            { "CDF", "CDF" },
-            { "CHE", "CHE" },
-            { "CHF", "CHF" },
-            { "CHW", "CHW" },
-            { "CLE", "CLE" },
-            { "CLF", "CLF" },
-            { "CLP", "CLP" },
-            { "CNH", "CNH" },
-            { "CNX", "CNX" },
             { "CNY", "CNY" },
-            { "COP", "COP" },
-            { "COU", "COU" },
-            { "CRC", "CRC" },
-            { "CSD", "CSD" },
-            { "CSK", "CSK" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CYP", "CYP" },
-            { "CZK", "CZK" },
-            { "DDM", "DDM" },
-            { "DEM", "DEM" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "ECS", "ECS" },
-            { "ECV", "ECV" },
-            { "EEK", "EEK" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
-            { "ESA", "ESA" },
-            { "ESB", "ESB" },
-            { "ESP", "ESP" },
-            { "ETB", "ETB" },
-            { "EUR", "EUR" },
-            { "FIM", "FIM" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "FRF", "FRF" },
             { "GBP", "GBP" },
-            { "GEK", "GEK" },
-            { "GEL", "GEL" },
-            { "GHC", "GHC" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GNS", "GNS" },
-            { "GQE", "GQE" },
-            { "GRD", "GRD" },
-            { "GTQ", "GTQ" },
-            { "GWE", "GWE" },
-            { "GWP", "GWP" },
-            { "GYD", "GYD" },
             { "HKD", "HKD" },
-            { "HNL", "HNL" },
-            { "HRD", "HRD" },
             { "HRK", "kn" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
-            { "IDR", "IDR" },
-            { "IEP", "IEP" },
-            { "ILP", "ILP" },
-            { "ILR", "ILR" },
             { "ILS", "ILS" },
             { "INR", "INR" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
-            { "ISJ", "ISJ" },
-            { "ISK", "ISK" },
-            { "ITL", "ITL" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
             { "JPY", "JPY" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
-            { "KRH", "KRH" },
-            { "KRO", "KRO" },
             { "KRW", "KRW" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LSL", "LSL" },
-            { "LTL", "LTL" },
-            { "LTT", "LTT" },
-            { "LUC", "LUC" },
-            { "LUF", "LUF" },
-            { "LUL", "LUL" },
-            { "LVL", "LVL" },
-            { "LVR", "LVR" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MAF", "MAF" },
-            { "MCF", "MCF" },
-            { "MDC", "MDC" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MGF", "MGF" },
-            { "MKD", "MKD" },
-            { "MKN", "MKN" },
-            { "MLF", "MLF" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
-            { "MRU", "MRU" },
-            { "MTL", "MTL" },
-            { "MTP", "MTP" },
-            { "MUR", "MUR" },
-            { "MVP", "MVP" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
             { "MXN", "MXN" },
-            { "MXP", "MXP" },
-            { "MXV", "MXV" },
-            { "MYR", "MYR" },
-            { "MZE", "MZE" },
-            { "MZM", "MZM" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
-            { "NIC", "NIC" },
-            { "NIO", "NIO" },
-            { "NLG", "NLG" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
             { "NZD", "NZD" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEI", "PEI" },
-            { "PEN", "PEN" },
-            { "PES", "PES" },
-            { "PGK", "PGK" },
             { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
-            { "PLZ", "PLZ" },
-            { "PTE", "PTE" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RHD", "RHD" },
-            { "ROL", "ROL" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
-            { "RUR", "RUR" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDD", "SDD" },
-            { "SDG", "SDG" },
-            { "SDP", "SDP" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
-            { "SIT", "SIT" },
-            { "SKK", "SKK" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SRG", "SRG" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
-            { "STN", "STN" },
-            { "SUR", "SUR" },
-            { "SVC", "SVC" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJR", "TJR" },
-            { "TJS", "TJS" },
-            { "TMM", "TMM" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TPE", "TPE" },
-            { "TRL", "TRL" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
             { "TWD", "TWD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
-            { "UAK", "UAK" },
-            { "UGS", "UGS" },
-            { "UGX", "UGX" },
             { "USD", "USD" },
-            { "USN", "USN" },
-            { "USS", "USS" },
-            { "UYI", "UYI" },
-            { "UYP", "UYP" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEB", "VEB" },
-            { "VEF", "VEF" },
-            { "VES", "VES" },
             { "VND", "VND" },
-            { "VNN", "VNN" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "XAG", "XAG" },
-            { "XAU", "XAU" },
-            { "XBA", "XBA" },
-            { "XBB", "XBB" },
-            { "XBC", "XBC" },
-            { "XBD", "XBD" },
             { "XCD", "XCD" },
-            { "XDR", "XDR" },
-            { "XEU", "XEU" },
-            { "XFO", "XFO" },
-            { "XFU", "XFU" },
-            { "XPD", "XPD" },
             { "XPF", "XPF" },
-            { "XPT", "XPT" },
-            { "XRE", "XRE" },
-            { "XSU", "XSU" },
-            { "XTS", "XTS" },
-            { "XUA", "XUA" },
             { "XXX", "XXX" },
-            { "YDD", "YDD" },
-            { "YER", "YER" },
-            { "YUD", "YUD" },
-            { "YUM", "YUM" },
-            { "YUN", "YUN" },
-            { "YUR", "YUR" },
-            { "ZAL", "ZAL" },
-            { "ZAR", "ZAR" },
-            { "ZMK", "ZMK" },
-            { "ZMW", "ZMW" },
-            { "ZRN", "ZRN" },
-            { "ZRZ", "ZRZ" },
-            { "ZWD", "ZWD" },
-            { "ZWL", "ZWL" },
-            { "ZWR", "ZWR" },
             { "adp", "andorska pezeta" },
             { "aed", "UAE dirham" },
             { "afa", "afganistanski afgani (1927.\u20132002.)" },
@@ -536,7 +256,7 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "mnt", "mongolski tugrik" },
             { "mop", "makao\u0161ka pataka" },
             { "mro", "mauritanijska ouguja (1973. \u2013 2017.)" },
-            { "mru", "mauritanijska ouguja" },
+            { "mru", "mauretanska ouguja" },
             { "mtl", "malte\u0161ka lira" },
             { "mtp", "malte\u0161ka funta" },
             { "mur", "mauricijska rupija" },
@@ -589,7 +309,8 @@ public class CurrencyNames_hr extends OpenListResourceBundle {
             { "shp", "svetohelenska funta" },
             { "sit", "slovenski tolar" },
             { "skk", "slova\u010dka kruna" },
-            { "sll", "sijeraleonski leone" },
+            { "sle", "sijeraleonski leone" },
+            { "sll", "sijeraleonski leone (1964\u20142022)" },
             { "sos", "somalijski \u0161iling" },
             { "srd", "surinamski dolar" },
             { "srg", "surinamski gulden" },
